@@ -7,15 +7,15 @@ PathLike = Union[str, Path]
 
 
 # TODO: use gitpython
-def call_git(command: str, cwd=None) -> str:
-    return subprocess.check_output(shlex.split(command), cwd=cwd, stderr=subprocess.DEVNULL).decode('utf-8').strip()
-
-
-def call(command: str, cwd=None) -> str:
+def call_git(command: str, cwd=None, wrap=False) -> str:
     try:
-        return subprocess.check_output(shlex.split(command), cwd=cwd).decode('utf-8').strip()
+        return subprocess.check_output(
+            shlex.split(command), cwd=cwd, stderr=subprocess.STD_ERROR_HANDLE if wrap else subprocess.DEVNULL
+        ).decode('utf-8').strip()
     except subprocess.CalledProcessError as e:
-        raise RuntimeError(e.stderr or e.stdout) from e
+        if wrap:
+            raise RuntimeError(e.stderr or e.stdout) from e
+        raise
 
 
 class HashNotFound(Exception):
